<?php 

namespace Teknisa\CNC\Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Notification;

use Teknisa\CNC\Services\Cnc00300ProdutoAdquirenteService;

use Teknisa\Libs\Util\Environment;

class Adquirentes extends \Teknisa\CNC\Controllers\TeknisaCrud {
    protected $dataSourceName = 'cnc00300_produtoadquirente_adquirentes';
	protected $parameterBagColumns;
	protected $produtoService;
	protected $environment;
	
	public function __construct($crudService, Cnc00300ProdutoAdquirenteService $produtoService, Environment $environment) {
        $this->crudService = $crudService;
        $this->produtoService = $produtoService;
        $this->environment = $environment;
    }
	
	public function save (DTO\Request $request, DTO\Response $response) {
	    try {
    	    $dataSet = $request->getDataSet();
            $rows = $dataSet->getRows();
            $currentTime = $this->environment->getCurrentTime()->format("d/m/Y H:i:s");
            
            foreach ($rows as $row) {
                
                if (is_object($row))
                    $row = (array) $row;
                    
                $row['NRORG'] = $this->environment->getNrOrgTrab();
                $row['IDATIVO'] = isset($row['IDATIVO']) ? ($row['IDATIVO'] ?: 'S') : 'S';
                $row['DTULTATU'] = $currentTime;
                $row['NRORGULTATU'] = $this->environment->getNrOrgTrab();
                $row['CDOPERULTATU'] = $this->environment->getCdOperador();
                if ($row['VRTOLERANCIA'] > 0.1)
                    throw new \Exception('A tolerância máxima é de R$0,10 (dez centavos).');
                if ($row['VRTAXAADM'] > 100)
                    throw new \Exception('Taxa superior ao limite de 100% (cem porcento).');
                    
                $row['VRTAXAADM'] = round($row['VRTAXAADM'], 5);
                
                $params = array(
                    ':VRTOLERANCIA'  => $row['VRTOLERANCIA'],
                    ':VRTAXAADM'     => $row['VRTAXAADM'],
                    ':NRTAXAADQPROD' => $row['NRTAXAADQPROD'],
                    ':DTULTATU'      => $row['DTULTATU'],
                    ':NRORGULTATU'   => $row['NRORGULTATU'],
                    ':CDOPERULTATU'  => $row['CDOPERULTATU'],
                    ':NRORG'         => $row['NRORG'],
                    ':IDATIVO'       => $row['IDATIVO']
                );
                
                $this->produtoService->saveAdquirente($params);
                $response->addNotification(new Notification("Dados salvos com sucesso!"), Notification::TYPE_SUCCESS);
            }
	    } catch (\Exception $e) {
	        $response->setError(new Error($e->getMessage(), 500));
	    }
	}
}