<?php
namespace Teknisa\CNC\Controllers;

use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Request;
use Teknisa\CNC\Services;
use Teknisa\CNC\Utilities;

class VendasCNC extends \Zeedhi\Framework\Controller\Simple {
    
    protected $vendaService;
    protected $salesMessage;
    protected $util;
    
    public function __construct(Services\VendasCNC $vendaService, Utilities\SalesMessageCNC $salesMessage, Utilities\Util $util) {
        $this->vendaService  = $vendaService;
        $this->salesMessage  = $salesMessage;
        $this->util          = $util;
    }

    public function getNoExistSells(Request\Filter $request, Response $response){
        try {
            $params = $request->getFilterCriteria()->getConditions();

            $resultado = $this->vendaService->getNoExistSells($params);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('Cnc00400_VendasInexAdquiRepo', $resultado));

        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    public function getConciliatorSells(Request\Filter $request, Response $response){
        try {
            $params = $request->getFilterCriteria()->getConditions();

            $vendaConciliada = $this->vendaService->getConciliatorSells($params);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('Cnc00600_GetVendasConciliadores', $vendaConciliada));

        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function getConciliatorSellsDetails(Request\Filter $request, Response $response){
        try {
            $params = $request->getFilterCriteria()->getConditions();

            $vendaConciliada = $this->vendaService->getConciliatorSellsDetails($params);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('Cnc00600_ConciliatorSellsDetailsRepo', $vendaConciliada));

        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function getAnticipatedSells(Request\Filter $request, Response $response){
        try {
            $conditions = $this->util->getParamsAsArray($request);
            $vendaConciliada = $this->vendaService->getAnticipatedSells($conditions);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('Cnc00900_VendasAntecipadasRepo', $vendaConciliada));

        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function loadAnticipatedSellsDetails(Request\Filter $request, Response $response){
        try {
            $conditions = $this->util->getParamsAsArray($request);
            $vendaConciliada = $this->vendaService->loadAnticipatedSellsDetails($conditions);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('Cnc00900_VendasAntecipadasDetalhesRepo', $vendaConciliada));

        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
}